==> lhcsmapi-1.2.19.tar.gz: lhcsmapi-1.2.19/lhcsmapi/gui/qh/QhDisplayModuleMediator.py <==
import os
from ipywidgets import Output, VBox
from IPython.display import clear_output
import matplotlib.pyplot as plt
import pandas as pd

from ...gui.ModuleMediator import ModuleMediator
from ...gui.qh.DateTimeBaseModule import DateTimeBaseModule
from ...gui.qh.QhBrowserAction import QhBrowserAction
from ...gui.qh.QhBrowserBaseModule import QhBrowserBaseModule
from ...gui.qh.QhSliderBaseModule import QhSliderBaseModule
from ...gui.qh.QuerySaveBaseModule import QuerySaveBaseModule


class QhDisplayModuleMediator(ModuleMediator):

    def __init__(self, date_time_module: DateTimeBaseModule, qh_browser_module: QhBrowserBaseModule,
                 query_save_module: QuerySaveBaseModule, qh_slider_module: QhSliderBaseModule) -> None:
        # register mediator
        self._date_time_module = date_time_module
        self._date_time_module.mediator = self
        self._qh_browser_module = qh_browser_module
        self._qh_browser_module.mediator = self
        self._query_save_module = query_save_module
        self._query_save_module.mediator = self
        self._qh_slider_module = qh_slider_module
        self._qh_slider_module.mediator = self

        self.out = Output()
        self.query_list = []
        self.discharges = pd.DataFrame()

        # load quench heater discharges
        cwd = os.path.dirname(__file__)
        full_path = os.path.join(str(cwd), 'RB_QH_2013_1_1-6-0-0_Timestamp_features.csv')
        self.qh_discharges_reduced = pd.read_csv(full_path, index_col=0)

        self.widget = VBox(children=[self._date_time_module.widget, self._qh_browser_module.widget,
                                     self._query_save_module.widget, self._qh_slider_module.widget])

        # display initial quench heater discharge list
        self._qh_slider_module.hide()
        with self.out:
            clear_output(True)
            self.display_discharge_list(self._qh_browser_module.get_state(),
                                        self._date_time_module.get_start_date_time(),
                                        self._date_time_module.get_end_date_time())

    def get_widget_and_out(self):
        return self.widget, self.out

    def notify(self, sender: object, event: str) -> None:
        state = self._qh_browser_module.get_state()
        start_date_time = self._date_time_module.get_start_date_time()
        end_date_time = self._date_time_module.get_end_date_time()

        if event == QhBrowserAction.QH_NAME_CHANGED or event == QhBrowserAction.DATE_CHANGED:
            self._qh_slider_module.hide()
            self._query_save_module.lbl_query.value = 'Press [Query] to load selected quench heater'
            self._query_save_module.progress_query.value = 0
            self._query_save_module.progress_query.description = ''
            with self.out:
                clear_output(True)
                self.display_discharge_list(state, start_date_time, end_date_time)

        elif event == QhBrowserAction.QUERY_BUTTON_CLICKED:
            self.discharges = self.get_discharge_list(state, start_date_time, end_date_time)
            self.query_list = self._query_save_module.query_signals(state, self.discharges)
            with self.out:
                clear_output(True)
                QhDisplayModuleMediator.plot_discharge(state.cir, self.query_list[0])
                self.display_discharge_list(state, start_date_time, end_date_time)
            self._qh_slider_module.show()
            self._qh_slider_module.slider_qh.max = len(self.discharges) - 1

        elif event == QhBrowserAction.SAVE_BUTTON_CLICKED:
            self._query_save_module.save_queries(self.query_list, self.discharges)

        elif event == QhBrowserAction.SLIDER_MOVED:
            index = self._qh_slider_module.get_value()
            with self.out:
                clear_output(True)
                QhDisplayModuleMediator.plot_discharge(state.cir, self.query_list[index])
                self.display_discharge_list(state, start_date_time, end_date_time)

        else:
            raise KeyError(f'Action {event} not supported!')

    def get_discharge_list(self, state, start_date_time, end_date_time):
        are_cells_selected = self.qh_discharges_reduced['magnet'] == state.qh
        qh_subselection = self.qh_discharges_reduced[are_cells_selected].reset_index().drop(columns=['index'])
        time_mask = (qh_subselection['date'] > start_date_time) & (qh_subselection['date'] < end_date_time)
        return qh_subselection.loc[time_mask].reset_index().drop(columns=['index'])

    def display_discharge_list(self, state, start_date_time, end_date_time):
        display(self.get_discharge_list(state, start_date_time, end_date_time))

    @staticmethod
    def plot_discharge(cir_type, discharge):
        n_subplots = 2 if cir_type == "RB" else 1
        fig, ax = plt.subplots(1, n_subplots, figsize=(10, 5))
        discharge.filter(regex=("U_HDS_\d{1}")).plot(ax=ax[0]).set(xlabel="[s]", ylabel="[V]")
        ax[0].grid(True)
        if cir_type == "RB":
            discharge.filter(regex=("I_HDS_\d{1}")).plot(ax=ax[1]).set(xlabel="[s]", ylabel="[A]")
            ax[1].grid(True)

==> lhcsmapi-1.2.111.tar.gz: lhcsmapi-1.2.111/lhcsmapi/gui/qh/QhDisplayModuleMediator.py <==
import os
from ipywidgets import Output, VBox
from IPython.display import clear_output
import matplotlib.pyplot as plt
import pandas as pd

from lhcsmapi.gui.ModuleMediator import ModuleMediator
from lhcsmapi.gui.qh.DateTimeBaseModule import DateTimeBaseModule
from lhcsmapi.gui.qh.QhBrowserAction import QhBrowserAction
from lhcsmapi.gui.qh.QhBrowserBaseModule import QhBrowserBaseModule
from lhcsmapi.gui.qh.QhSliderBaseModule import QhSliderBaseModule
from lhcsmapi.gui.qh.QuerySaveBaseModule import QuerySaveBaseModule


class QhDisplayModuleMediator(ModuleMediator):

    def __init__(self, date_time_module: DateTimeBaseModule, qh_browser_module: QhBrowserBaseModule,
                 query_save_module: QuerySaveBaseModule, qh_slider_module: QhSliderBaseModule) -> None:
        # register mediator
        self._date_time_module = date_time_module
        self._date_time_module.mediator = self
        self._qh_browser_module = qh_browser_module
        self._qh_browser_module.mediator = self
        self._query_save_module = query_save_module
        self._query_save_module.mediator = self
        self._qh_slider_module = qh_slider_module
        self._qh_slider_module.mediator = self

        self.out = Output()
        self.query_list = []
        self.discharges = pd.DataFrame()

        # load quench heater discharges
        cwd = os.path.dirname(__file__)
        full_path = os.path.join(str(cwd), 'RB_QH_2013_1_1-6-0-0_Timestamp_features.csv')
        self.qh_discharges_reduced = pd.read_csv(full_path, index_col=0)

        self.widget = VBox(children=[self._date_time_module.widget, self._qh_browser_module.widget,
                                     self._query_save_module.widget, self._qh_slider_module.widget])

        # display initial quench heater discharge list
        self._qh_slider_module.hide()
        with self.out:
            clear_output(True)
            self.display_discharge_list(self._qh_browser_module.get_state(),
                                        self._date_time_module.get_start_date_time(),
                                        self._date_time_module.get_end_date_time())

    def get_widget_and_out(self):
        return self.widget, self.out

    def notify(self, sender: object, event: str) -> None:
        state = self._qh_browser_module.get_state()
        start_date_time = self._date_time_module.get_start_date_time()
        end_date_time = self._date_time_module.get_end_date_time()

        if event == QhBrowserAction.QH_NAME_CHANGED or event == QhBrowserAction.DATE_CHANGED:
            self._qh_slider_module.hide()
            self._query_save_module.lbl_query.value = 'Press [Query] to load selected quench heater'
            self._query_save_module.progress_query.value = 0
            self._query_save_module.progress_query.description = ''
            with self.out:
                clear_output(True)
                self.display_discharge_list(state, start_date_time, end_date_time)

        elif event == QhBrowserAction.QUERY_BUTTON_CLICKED:
            self.discharges = self.get_discharge_list(state, start_date_time, end_date_time)
            self.query_list = self._query_save_module.query_signals(state, self.discharges)
            with self.out:
                clear_output(True)
                QhDisplayModuleMediator.plot_discharge(state.cir, self.query_list[0])
                self.display_discharge_list(state, start_date_time, end_date_time)
            self._qh_slider_module.show()
            self._qh_slider_module.slider_qh.max = len(self.discharges) - 1

        elif event == QhBrowserAction.SAVE_BUTTON_CLICKED:
            self._query_save_module.save_queries(self.query_list, self.discharges)

        elif event == QhBrowserAction.SLIDER_MOVED:
            index = self._qh_slider_module.get_value()
            with self.out:
                clear_output(True)
                QhDisplayModuleMediator.plot_discharge(state.cir, self.query_list[index])
                self.display_discharge_list(state, start_date_time, end_date_time)

        else:
            raise KeyError(f'Action {event} not supported!')

    def get_discharge_list(self, state, start_date_time, end_date_time):
        are_cells_selected = self.qh_discharges_reduced['magnet'] == state.qh
        qh_subselection = self.qh_discharges_reduced[are_cells_selected].reset_index().drop(columns=['index'])
        time_mask = (qh_subselection['date'] > start_date_time) & (qh_subselection['date'] < end_date_time)
        return qh_subselection.loc[time_mask].reset_index().drop(columns=['index'])

    def display_discharge_list(self, state, start_date_time, end_date_time):
        display(self.get_discharge_list(state, start_date_time, end_date_time))

    @staticmethod
    def plot_discharge(cir_type, discharge):
        n_subplots = 2 if cir_type == "RB" else 1
        fig, ax = plt.subplots(1, n_subplots, figsize=(10, 5))
        discharge.filter(regex=("U_HDS_\d{1}")).plot(ax=ax[0]).set(xlabel="[s]", ylabel="[V]")
        ax[0].grid(True)
        if cir_type == "RB":
            discharge.filter(regex=("I_HDS_\d{1}")).plot(ax=ax[1]).set(xlabel="[s]", ylabel="[A]")
            ax[1].grid(True)
